@@ -1,6 +1,7 @@
 import logging
 import sys
 from web3 import Web3
+import dex.erc20 as erc20
 import consumable.consumable as consumable
 
 if __name__ == "__main__":
@@ -10,10 +11,11 @@ if __name__ == "__main__":
     logger.setLevel(logging.DEBUG)
     logging.basicConfig(level=logging.INFO, format=log_format, stream=sys.stdout)
 
-    rpc_server = 'https://api.harmony.one'
+    rpc_server = 'https://klaytn.rpc.defikingdoms.com/'
     logger.info("Using RPC server " + rpc_server)
 
-    stamina_vial_address = '0x959ba19508827d1ed2333B1b503Bd5ab006C710e'
+    stamina_vial_address = erc20.symbol2address('DFKSTMNPTN', 'sd2')
+    realm_consumable_contract_address = consumable.SERENDALE2_CONTRACT_ADDRESS
 
     w3 = Web3(Web3.HTTPProvider(rpc_server))
     private_key = None  # set private key
@@ -22,4 +24,4 @@ if __name__ == "__main__":
     tx_timeout_seconds = 30
 
     hero_id = 1
-    consumable.consume_item(consumable.SERENDALE_CONTRACT_ADDRESS, stamina_vial_address, hero_id, private_key, w3.eth.getTransactionCount(account_address), gas_price_gwei, tx_timeout_seconds, rpc_server, logger)
\ No newline at end of file
+    consumable.consume_item(realm_consumable_contract_address, stamina_vial_address, hero_id, private_key, w3.eth.getTransactionCount(account_address), gas_price_gwei, tx_timeout_seconds, rpc_server, logger)
\ No newline at end of file
