@@ -3,3 +3,6 @@ SERENDALE_JEWEL_QUEST_CONTRACT_ADDRESS = '0x6FF019415Ee105aCF2Ac52483A33F5B43eaD
 
 CRYSTALVALE_GOLD_QUEST_CONTRACT_ADDRESS = '0x75912145f5cFEfb980616FA47B2f103210FaAb94'
 CRYSTALVALE_CRYSTAL_QUEST_CONTRACT_ADDRESS = '0x98b3C85ac3cC3EF36Ff25A9229857AbACE3e7410'
+
+SERENDALE2_GOLD_QUEST_CONTRACT_ADDRESS = '0x46F036B26870188aD69877621815238D2b81bef1'
+SERENDALE2_JADE_QUEST_CONTRACT_ADDRESS = '0x20B274262FA6da57B5Ff90498EC373c0266eF901'
\ No newline at end of file
